@@ -1,4 +1,5 @@
 #![warn(missing_docs)]
+#![deny(unconditional_recursion)]
 //! Tells when responses can be reused from a cache, taking into account [HTTP RFC 7234](http://httpwg.org/specs/rfc7234.html) rules for user agents and shared caches.
 //! It's aware of many tricky details such as the `Vary` header, proxy revalidation, and authenticated responses.
 
@@ -792,6 +793,18 @@ impl<Body> RequestLike for Request<Body> {
     }
 }
 
+impl RequestLike for http::request::Parts {
+    fn uri(&self) -> &Uri {
+        &self.uri
+    }
+    fn method(&self) -> &Method {
+        &self.method
+    }
+    fn headers(&self) -> &HeaderMap {
+        &self.headers
+    }
+}
+
 impl<Body> ResponseLike for Response<Body> {
     fn status(&self) -> StatusCode {
         self.status()
@@ -800,3 +813,12 @@ impl<Body> ResponseLike for Response<Body> {
         self.headers()
     }
 }
+
+impl ResponseLike for http::response::Parts {
+    fn status(&self) -> StatusCode {
+        self.status
+    }
+    fn headers(&self) -> &HeaderMap {
+        &self.headers
+    }
+}
